Discover Packages
github.com/hl/brr
internal
config
package
Version:
v0.2.0
Opens a new window with list of versions in this module.
Published: Mar 29, 2026
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type Config struct {
Default string `mapstructure:"default"`
Profiles map[string ]Profile `mapstructure:"profiles"`
}
Config holds all brr configuration.
Load reads config from files and returns a merged Config.
Priority: .brr.yaml > ~/.config/brr/config.yaml.
Returns an error if no config is found or if a config file is malformed.
ResolveProfile returns the command slice for the given profile name.
If profileName is empty, the default profile is used.
type Profile struct {
Command string `mapstructure:"command"`
Args []string `mapstructure:"args"`
}
Profile defines a named agent configuration.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.