engine

package
v0.1.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 28, 2026 License: MIT Imports: 14 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ErrInterrupted = fmt.Errorf("interrupted")

ErrInterrupted is returned when the engine is stopped by a user signal (Ctrl+C).

Functions

func Run

func Run(opts Options) error

Run executes the loop until completion, max iterations, or interrupt.

Types

type Options

type Options struct {
	Prompt  string   // resolved prompt text
	Max     int      // max iterations (0 = unlimited)
	Command []string // command + args to run (prompt piped to stdin)
}

Options configures a loop run.

Jump to