Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Send ¶
Send dispatches a best-effort desktop notification for the given engine result. It returns an error if the notification could not be sent, but callers should treat failures as non-fatal.
func SendWorkflowError ¶ added in v0.3.6
SendWorkflowError dispatches a notification for workflow errors that happen before the engine can return a structured stop reason.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.