notify

package
v0.3.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 26, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Send

func Send(result *engine.Result) error

Send dispatches a best-effort desktop notification for the given engine result. It returns an error if the notification could not be sent, but callers should treat failures as non-fatal.

Types

This section is empty.

Jump to